@@ -3,6 +3,10 @@ import colorlog
 import re
 import os
 from cvnn.utils import create_folder
+from tensorflow.keras.utils import get_custom_objects
+from cvnn.activations import act_dispatcher
+
+get_custom_objects().update(act_dispatcher)     # Makes my activation functions usable with a simple string
 
 
 def get_version() -> str:
@@ -36,9 +40,9 @@ __status__ = '{dev_status}'
 
 STRING_FORMATTER = "%(asctime)s — %(levelname)s - %(module)s::%(funcName)s line %(lineno)s — %(message)s"
 
-file_handler = logging.FileHandler(create_folder("./log/logs/") / "logs.log")
-formatter = logging.Formatter(STRING_FORMATTER)
-file_handler.setFormatter(formatter)
+# file_handler = logging.FileHandler(create_folder("./log/logs/") / "logs.log")
+# formatter = logging.Formatter(STRING_FORMATTER)
+# file_handler.setFormatter(formatter)
 
 # https://github.com/borntyping/python-colorlog
 # https://stackoverflow.com/a/23964880/5931672
@@ -48,7 +52,7 @@ console_handler.setFormatter(colorlog.ColoredFormatter('%(log_color)s' + STRING_
 logger = colorlog.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 logger.addHandler(console_handler)
-logger.addHandler(file_handler)
+# logger.addHandler(file_handler)
 
 
 
